Merge branch 'master' into lxc
authorMarco Yuen <marcoy@gmail.com>
Wed, 14 Dec 2011 17:13:36 +0000 (12:13 -0500)
committerMarco Yuen <marcoy@gmail.com>
Wed, 14 Dec 2011 17:13:36 +0000 (12:13 -0500)
Conflicts:
onelab-k32-tags.mk
planetlab-k32-tags.mk

mirroring/f15/yum.repos.d/building.repo.in [deleted file]
mirroring/f16/yum.repos.d/building.repo.in [new file with mode: 0644]
onelab-k32-tags.mk
pkgs.py
planetlab-k27-tags.mk
planetlab-k32-tags.mk
vbuild-init-vserver.sh

diff --git a/mirroring/f15/yum.repos.d/building.repo.in b/mirroring/f15/yum.repos.d/building.repo.in
deleted file mode 100644 (file)
index af9fd91..0000000
+++ /dev/null
@@ -1,16 +0,0 @@
-[fedora]
-name=Fedora 15 - $basearch
-baseurl=@MIRRORURL@/fedora/releases/15/Everything/$basearch/os/
-enabled=1
-metadata_expire=7d
-gpgcheck=1
-gpgkey=http://mirror.onelab.eu/keys/RPM-GPG-KEY-fedora-15-primary
-
-[updates]
-name=Fedora 15 - $basearch - Updates
-baseurl=@MIRRORURL@/fedora/updates/15/$basearch/
-enabled=1
-metadata_expire=7d
-gpgcheck=1
-gpgkey=http://mirror.onelab.eu/keys/RPM-GPG-KEY-fedora-15-primary
-
diff --git a/mirroring/f16/yum.repos.d/building.repo.in b/mirroring/f16/yum.repos.d/building.repo.in
new file mode 100644 (file)
index 0000000..cc06365
--- /dev/null
@@ -0,0 +1,16 @@
+[fedora]
+name=Fedora 16 - $basearch
+baseurl=@MIRRORURL@/fedora/releases/16/Everything/$basearch/os/
+enabled=1
+metadata_expire=7d
+gpgcheck=1
+gpgkey=http://mirror.onelab.eu/keys/RPM-GPG-KEY-fedora-16-primary
+
+[updates]
+name=Fedora 16 - $basearch - Updates
+baseurl=@MIRRORURL@/fedora/updates/16/$basearch/
+enabled=1
+metadata_expire=7d
+gpgcheck=1
+gpgkey=http://mirror.onelab.eu/keys/RPM-GPG-KEY-fedora-16-primary
+
index eb75cb1..61f15cd 100644 (file)
@@ -4,8 +4,8 @@
 linux-2.6-BRANCH               := rhel6
 linux-2.6-GITPATH               := git://git.onelab.eu/linux-2.6.git@linux-2.6-32-27
 # help out spec2make on f8 and centos5, due to a bug in rpm 
-# ditto on f15 for spec2make.py - tmp hopefully
-ifeq "$(DISTRONAME)" "$(filter $(DISTRONAME),f8 f15 centos5)"
+# ditto on f16 for spec2make.py - tmp hopefully
+ifeq "$(DISTRONAME)" "$(filter $(DISTRONAME),f8 f16 centos5)"
 kernel-WHITELIST-RPMS  := kernel-devel,kernel-headers
 endif
 kernel-DEVEL-RPMS              += elfutils-libelf-devel
@@ -25,7 +25,7 @@ libnl-GITPATH                 := git://git.onelab.eu/libnl.git@libnl-1.1-2
 util-vserver-pl-GITPATH         := git://git.onelab.eu/util-vserver-pl.git@util-vserver-pl-0.4-26
 nodeupdate-GITPATH              := git://git.onelab.eu/nodeupdate.git@nodeupdate-0.5-9
 PingOfDeath-SVNPATH            := http://svn.planet-lab.org/svn/PingOfDeath/tags/PingOfDeath-2.2-1
-nodemanager-GITPATH             := git://git.planet-lab.org/nodemanager.git@lxcbuild
+nodemanager-GITPATH             := git://git.onelab.eu/nodemanager.git@nodemanager-2.0-34
 pl_sshd-SVNPATH                        := http://svn.planet-lab.org/svn/pl_sshd/tags/pl_sshd-1.0-11
 codemux-GITPATH                        := git://git.onelab.eu/codemux.git@codemux-0.1-15
 fprobe-ulog-SVNPATH             := http://svn.planet-lab.org/svn/fprobe-ulog/tags/fprobe-ulog-1.1.3-3
@@ -49,8 +49,8 @@ ejabberd-GITPATH              := git://git.onelab.eu/ejabberd.git@ejabberd-2.1.6-2
 omf-GITPATH                     := git://git.onelab.eu/omf.git@omf-5.3-11
 oml-GITPATH                     := git://git.onelab.eu/oml.git@oml-2.6.1-1
 ###
-sfa-GITPATH                     := git://git.onelab.eu/sfa.git@sfa-2.0-2
-sface-GITPATH                   := git://git.onelab.eu/sface.git@master
+sfa-GITPATH                     := git://git.onelab.eu/sfa.git@sfa-2.0-4
+sface-GITPATH                   := git://git.onelab.eu/sface.git@sface-0.9-0
 nodeconfig-GITPATH              := git://git.onelab.eu/nodeconfig.git@nodeconfig-5.0-5
 bootmanager-GITPATH             := git://git.planet-lab.org/bootmanager.git@lxcbuild
 pypcilib-GITPATH               := git://git.onelab.eu/pypcilib.git@pypcilib-0.2-10
diff --git a/pkgs.py b/pkgs.py
index 1f4a7f1..cccd7ea 100755 (executable)
--- a/pkgs.py
+++ b/pkgs.py
@@ -34,7 +34,7 @@ import re
 default_arch='x86_64'
 known_arch = ['i386','x86_64']
 default_fcdistro='f12'
-known_fcdistros = [ 'centos5','centos6','f8', 'f9','f10','f11','f12', 'f13', 'f14', 'f15', 'sl6']
+known_fcdistros = [ 'centos5','centos6','f8', 'f9','f10','f11','f12', 'f13', 'f14', 'f16', 'sl6']
 default_pldistro='onelab'
 
 known_keywords=['groupname', 'groupdesc', 'kexclude', 'package', 'group', 'precious', 'junk', 'mirror', ]
index 1d344f8..2bdba31 100644 (file)
@@ -9,7 +9,7 @@ libnl-GITPATH                   := git://git.planet-lab.org/libnl.git@libnl-1.1-2
 util-vserver-pl-GITPATH                := git://git.planet-lab.org/util-vserver-pl.git@util-vserver-pl-0.4-26
 nodeupdate-GITPATH             := git://git.planet-lab.org/nodeupdate.git@nodeupdate-0.5-9
 PingOfDeath-SVNPATH            := http://svn.planet-lab.org/svn/PingOfDeath/tags/PingOfDeath-2.2-1
-nodemanager-GITPATH             := git://git.planet-lab.org/nodemanager.git@nodemanager-2.0-33
+nodemanager-GITPATH             := git://git.planet-lab.org/nodemanager.git@nodemanager-2.0-34
 # Trellis-specific NodeManager plugins
 nodemanager-topo-GITPATH       := git://git.planet-lab.org/NodeManager-topo@master
 NodeManager-optin-SVNPATH      := http://svn.planet-lab.org/svn/NodeManager-optin/trunk
@@ -35,7 +35,7 @@ pyaspects-GITPATH             := git://git.planet-lab.org/pyaspects.git@pyaspects-0.4.1-2
 ejabberd-GITPATH               := git://git.planet-lab.org/ejabberd.git@ejabberd-2.1.6-2
 omf-GITPATH                     := git://git.onelab.eu/omf.git@omf-5.3-11
 ###
-sfa-GITPATH                     := git://git.planet-lab.org/sfa.git@sfa-2.0-2
+sfa-GITPATH                     := git://git.planet-lab.org/sfa.git@sfa-2.0-4
 nodeconfig-GITPATH             := git://git.planet-lab.org/nodeconfig.git@nodeconfig-5.0-5
 pypcilib-GITPATH               := git://git.planet-lab.org/pypcilib.git@pypcilib-0.2-10
 pyplnet-GITPATH                 := git://git.planet-lab.org/pyplnet.git@pyplnet-4.3-11
@@ -47,4 +47,4 @@ vserver-reference-GITPATH       := git://git.planet-lab.org/vserver-reference.gi
 bootstrapfs-GITPATH             := git://git.planet-lab.org/bootstrapfs.git@bootstrapfs-2.0-13
 myplc-GITPATH                   := git://git.planet-lab.org/myplc.git@myplc-5.0-19
 # locating the right test directory - see make tests_gitpath
-tests-GITPATH                   := git://git.planet-lab.org/tests.git@tests-5.0-31
+tests-GITPATH                   := git://git.planet-lab.org/tests.git@tests-5.0-32
index 6d969b8..66eab4e 100644 (file)
@@ -44,8 +44,8 @@ pyaspects-GITPATH             := git://git.planet-lab.org/pyaspects.git@pyaspects-0.4.1-2
 ejabberd-GITPATH               := git://git.planet-lab.org/ejabberd.git@ejabberd-2.1.6-2
 omf-GITPATH                     := git://git.onelab.eu/omf.git@omf-5.3-11
 ###
-sfa-GITPATH                     := git://git.planet-lab.org/sfa.git@sfa-2.0-2
-sface-GITPATH                   := git://git.planet-lab.org/sface.git@master
+sfa-GITPATH                     := git://git.planet-lab.org/sfa.git@sfa-2.0-4
+sface-GITPATH                   := git://git.planet-lab.org/sface.git@sface-0.9-0
 nodeconfig-GITPATH             := git://git.planet-lab.org/nodeconfig.git@nodeconfig-5.0-5
 bootmanager-GITPATH             := git://git.planet-lab.org/bootmanager.git@lxcbuild
 pypcilib-GITPATH               := git://git.planet-lab.org/pypcilib.git@pypcilib-0.2-10
@@ -57,4 +57,4 @@ vserver-reference-GITPATH       := git://git.planet-lab.org/vserver-reference.gi
 bootstrapfs-GITPATH             := git://git.planet-lab.org/bootstrapfs.git@bootstrapfs-2.0-13
 myplc-GITPATH                   := git://git.planet-lab.org/myplc.git@myplc-5.0-19
 # locating the right test directory - see make tests_gitpath
-tests-GITPATH                   := git://git.planet-lab.org/tests.git@tests-5.0-31
+tests-GITPATH                   := git://git.planet-lab.org/tests.git@tests-5.0-32
index 3f69cd9..7aed817 100755 (executable)
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_SYS_ADMIN $BCAPFILE || echo CAP_SYS_ADMIN >> $BCAPFILE
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_IPC_LOCK $BCAPFILE || echo CAP_IPC_LOCK >> $BCAPFILE
# useful for f15 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     else
        ### capabilities required for a myplc vserver
        # for /etc/plc.d/gpg - need to init /dev/random
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_NET_BIND_SERVICE $BCAPFILE || echo CAP_NET_BIND_SERVICE >> $BCAPFILE
# useful for f15 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     fi
 
@@ -192,8 +192,8 @@ function setup_vserver () {
     # Enable cgroup
     mkdir /etc/vservers/$vserver/cgroup
 
# Set the init style of your vserver to plain for f15 and higher
# not working with f15 anyways, systemd requires 2.6.36 to work
     case $fcdistro in 
        f1[5-9]) echo plain > /etc/vservers/$vserver/apps/init/style ;;
     esac
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_IPC_LOCK $BCAPFILE || echo CAP_IPC_LOCK >> $BCAPFILE
-       # useful for f15 guests that use set_cap_file 
+       # useful for f16 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     else
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_NET_BIND_SERVICE $BCAPFILE || echo CAP_NET_BIND_SERVICE >> $BCAPFILE
-       # useful for f15 guests that use set_cap_file 
+       # useful for f16 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     fi
@@ -192,8 +192,8 @@ function setup_vserver () {
     mkdir /etc/vservers/$vserver/cgroup
 
-    # Set the init style of your vserver to plain for f15 and higher
-    # not working with f15 anyways, systemd requires 2.6.36 to work
+    # Set the init style of your vserver to plain for f16 and higher
+    # not working with f16 anyways, systemd requires 2.6.36 to work
     case $fcdistro in 
        f1[5-9]) echo plain > /etc/vservers/$vserver/apps/init/style ;;